#ifndef _ENGINE_INTERFACES_H
#define _ENGINE_INTERFACES_H


#define ENGINE_INTERFACE_VERSION	2

#define MOVES_UCI					1

typedef struct tagEngineProperties {
	DWORD dwSize;		// Structure size, will help when interface version changes
	DWORD dwVersion;	// Version of the interface
	DWORD dwCaps;
	TCHAR sEngineName[32];
} EngineProperties;



interface IEngine {
	virtual BOOL GetProperties(EngineProperties *pProps) = 0;
	virtual void StartGame(BOOL bPlayBlack, BOOL bAnalyze, LPCTSTR sFen) = 0;
	virtual void EndGame() = 0;
	virtual void Release() = 0;
	virtual void SendMove(LPCTSTR sMove) = 0;
	virtual BOOL ShowOptions(HWND hWnd) = 0;
	virtual HMENU GetMenu() = 0;
	virtual BOOL HandleCommand(HWND hWnd, WPARAM wParam, LPARAM lParam) = 0;
	virtual void SetPosition(LPCTSTR sFEN) = 0;
	virtual void MoveNow() = 0;
	virtual BOOL IsAlive() = 0;
	virtual void GetMessages(BOOL bWantMessages) = 0;
};

interface ICEBoard20 {
	// Mthodes de la version 1
	virtual void EngineMove(LPCTSTR sMove) = 0;
	virtual void FatalError(LPCTSTR sError) = 0;
	virtual void GameFinished(LPCTSTR sResult, LPCTSTR sComment) = 0;
//	virtual void EngineMessage(LPCTSTR sMessage, BOOL bNew) = 0; // Supprime en V2
	virtual void WhoPlays(LPCTSTR sPlayer) = 0;
	virtual void SwitchSides() = 0;
	virtual void ShowThinking(BOOL bShow) = 0;
	virtual void SetTimeControl(int nSecByMove, int nMoves1, int nSec1, int nMoves2, int nSec2, int nSec3, int nInc) = 0;
	// Nouvelle mthode remplaant EngineMessage
	// Attention : chanes passe en ANSI pour viter les recopies inutiles
	virtual void EngineFeedback(int depth, int nodesSec, int totalNodes, int nTime, LPCSTR sEval, LPCSTR sVariante) = 0;
	// Mthode ajoute pour passer l'information de temps  l'UCI
	virtual void GetTimeInfo(int *pwtime, int *pbtime, int *pmovestogo) = 0;
};


typedef IEngine *LPENGINE;

typedef LPENGINE (*LoadEngineProc)(ICEBoard20 *pCEBoard);

#define EngineProcName L"LoadEngine"



#endif